﻿/*!
 * Copyright(c) 2018 Yaron Guan Golan
 *
 * Recipe that leverages the updated html-to-docx (https://github.com/privateOmega/html-to-docx)
 */

const path = require('path')
const { response } = require('jsreport-office')
const extend = require('node.extend.without.arrays')

module.exports = (reporter, definition) => {
  definition.options = extend(true, { preview: {} }, reporter.options.office, definition.options)

  reporter.extensionsManager.recipes.push({
    name: 'HTMLtoDOCX',
    execute: async function (req, res) {
      console.log(req.template);
      const result = await reporter.executeScript({
        htmlContent: res.content.toString(),
        properties: req.template.chrome
      }, {
        execModulePath: path.join(__dirname, 'htmlToDocx.js')
      }, req)

      if (result.error) {
        const error = new Error(result.error.message)
        error.stack = result.error.stack

        throw reporter.createError('Error creating docx', {
          original: error,
          weak: true
        })
      }

      return response({
        previewOptions: definition.options.preview,
        officeDocumentType: 'docx',
        buffer: Buffer.from(result.docxContent, 'base64')
      }, req, res)
    }
  })

  reporter.initializeListeners.add(definition.name, () => {
    if (reporter.express) {
      reporter.express.exposeOptionsToApi(definition.name, {
        preview: {
          enabled: definition.options.preview.enabled,
          showWarning: definition.options.preview.showWarning
        }
      })
    }
  })
}
